@@ -1,4 +1,5 @@
-use std::{
+use core::{
+    borrow::Borrow,
     convert::TryFrom,
     iter::IntoIterator,
     ops::{Index, IndexMut, Range, RangeFull},
@@ -74,3 +75,9 @@ impl Index<RangeFull> for Sheet {
         &self.0[r]
     }
 }
+
+impl Borrow<[Moment]> for Sheet {
+    fn borrow(&self) -> &[Moment] {
+        &self.0[..]
+    }
+}
