@@ -29,7 +29,7 @@ pub trait Timer {
     ///
     /// # Note
     /// The default implementation modifies `self` if a tempo event is found.
-    fn track_len(&mut self, moments: &[Moment]) -> Duration {
+    fn duration(&mut self, moments: &[Moment]) -> Duration {
         let mut total = Duration::default();
         let mut empty_counter = 0;
         for moment in moments {
@@ -37,7 +37,7 @@ pub trait Timer {
                 Moment::Empty => empty_counter += 1,
                 Moment::Events(events) => {
                     total += Duration::from_micros(
-                        (empty_counter as f64 + self.tick_len_micros()) as u64,
+                        (empty_counter as f64 * self.tick_len_micros()) as u64,
                     );
                     empty_counter = 0;
                     for event in events {
@@ -105,14 +105,6 @@ impl Timer for Ticker {
     }
 }
 
-impl Timer for f64 {
-    fn tick_len_micros(&self) -> f64 {
-        *self
-    }
-
-    fn change_tempo(&mut self, _: u32) {}
-}
-
 impl TryFrom<Timing> for Ticker {
     type Error = Box<dyn std::error::Error>;
 
